https://github.com/0xG-MSK
<-----A Simply DataBase Simulation---->
- This DB works by accepting user data passing it in an algorithm and saving it in csv format
- Data can also be retrieved by accessing the data structures directly

- tips: some data structures like *standard and *series need no name to function, at that parameter "None" can be passed

- this is just a very small and simple program to help with small projects
- there will be further updates of this module
- and also there may be bugs, if encountered - contact me manassekpormegbe@gmail.com
- this is was created by a 15 yr old :|
- #<-------join a community of DeVs and share your thoughts https://chat.whatsapp.com/Liof7yBVcC5Cbk95GQSI---------->